pub struct TestNetZoneAddr(pub u32);Expand description
An address on the test network
Tuple Fields
0: u32Trait Implementations
Sourceimpl BorshDeserialize for TestNetZoneAddr
impl BorshDeserialize for TestNetZoneAddr
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for TestNetZoneAddr
impl BorshSerialize for TestNetZoneAddr
Sourceimpl Clone for TestNetZoneAddr
impl Clone for TestNetZoneAddr
Sourcefn clone(&self) -> TestNetZoneAddr
fn clone(&self) -> TestNetZoneAddr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TestNetZoneAddr
Sourceimpl Debug for TestNetZoneAddr
impl Debug for TestNetZoneAddr
Sourceimpl Display for TestNetZoneAddr
impl Display for TestNetZoneAddr
impl Eq for TestNetZoneAddr
Sourceimpl From<TestNetZoneAddr> for NetworkAddress
impl From<TestNetZoneAddr> for NetworkAddress
Sourcefn from(value: TestNetZoneAddr) -> Self
fn from(value: TestNetZoneAddr) -> Self
Converts to this type from the input type.
Sourceimpl Hash for TestNetZoneAddr
impl Hash for TestNetZoneAddr
Sourceimpl NetZoneAddress for TestNetZoneAddr
impl NetZoneAddress for TestNetZoneAddr
Sourcetype BanID = TestNetZoneAddr
type BanID = TestNetZoneAddr
Cuprate needs to be able to ban peers by IP addresses and not just by
SocketAddr as
that include the port, to be able to facilitate this network addresses must have a ban ID
which for hidden services could just be the address it self but for clear net addresses will
be the IP address. Read moreSourcefn make_canonical(&mut self)
fn make_canonical(&mut self)
Turns this address into its canonical form.
Sourcefn ban_id(&self) -> Self::BanID
fn ban_id(&self) -> Self::BanID
Returns the
Self::BanID for this address.fn should_add_to_peer_list(&self) -> bool
Sourceimpl PartialEq for TestNetZoneAddr
impl PartialEq for TestNetZoneAddr
impl StructuralPartialEq for TestNetZoneAddr